@@ -9,6 +9,8 @@ def temporary_dynamodb_table(
         table_name,
         hashkey_name,
         hashkey_type="S",
+        sortkey_name=None,
+        sortkey_type="S",
         delay=5.0,
         max_attempts=10,):
     """
@@ -22,6 +24,10 @@ def temporary_dynamodb_table(
         Name of the hash key of the table
     hashkey_type : str, optional
         Type of the hash key ("S", "N", or "B"). Default "S"
+    sortkey_name : str, optional
+        Optional sort key for the temporary table
+    sortkey_type : str, optional
+        Type of the sort key if there is one ("S", "N", or "B"). Default "S"
     delay : float, optional
         Delay in seconds between checks if the table exists
     max_attempts : int, optional
@@ -33,20 +39,36 @@ def temporary_dynamodb_table(
 
     dynamodb = DynamoDB()
 
+    attribute_definitions = [
+        {
+            'AttributeName': hashkey_name,
+            'AttributeType': hashkey_type,
+        },
+    ]
+    key_schema = [
+        {
+            'AttributeName': hashkey_name,
+            'KeyType': 'HASH',
+        },
+    ]
+    if sortkey_name is not None and sortkey_type is not None:
+        attribute_definitions.append(
+            {
+                'AttributeName': sortkey_name,
+                'AttributeType': sortkey_type,
+            }
+        )
+        key_schema.append(
+            {
+                'AttributeName': sortkey_name,
+                'KeyType': 'RANGE',
+            },
+        )
+
     dynamodb.client.create_table(
-        AttributeDefinitions=[
-            {
-                'AttributeName': hashkey_name,
-                'AttributeType': hashkey_type,
-            },
-        ],
         TableName=table_name,
-        KeySchema=[
-            {
-                'AttributeName': hashkey_name,
-                'KeyType': 'HASH',
-            },
-        ],
+        AttributeDefinitions=attribute_definitions,
+        KeySchema=key_schema,
         ProvisionedThroughput={
             'ReadCapacityUnits': 123,
             'WriteCapacityUnits': 123
