@@ -13,20 +13,39 @@ class TestTemporaryDynamoDBTable(unittest.TestCase):
 
         self.assertNotIn(
             "test_table_name",
-            dynamodb.tables
+            dynamodb.list_tables()
         )
 
         with temporary_dynamodb_table("test_table_name", "test_hashkey_name"):
             self.assertIn(
                 "test_table_name",
-                dynamodb.tables
+                dynamodb.list_tables()
             )
 
         self.assertNotIn(
             "test_table_name",
-            dynamodb.tables
+            dynamodb.list_tables()
         )
 
+    def test_create_dynamodb_table_composite_key(self):
+        dynamodb = DynamoDB()
+
+        with temporary_dynamodb_table(
+            "test_table_name",
+            "test_hashkey_name",
+            sortkey_name="sortkey_name",
+        ):
+            self.assertIn(
+                "test_table_name",
+                dynamodb.list_tables()
+            )
+            table_desc = dynamodb.client.describe_table(
+                TableName="test_table_name",
+            )
+
+        # Both a hash and sort key
+        self.assertEqual(len(table_desc["Table"]["KeySchema"]), 2)
+
     def test_create_dynamodb_table_fails(self):
         fake_client = mock.Mock()
 
